@@ -2,7 +2,7 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 
 """
-This module contains utililies used for constructing rotation matrices.
+Utililies used for constructing and inspecting rotation matrices.
 """
 from functools import reduce
 import numpy as np
@@ -44,15 +44,15 @@ def rotation_matrix(angle, axis='z', unit=None):
 
     Parameters
     ----------
-    angle : convertible to `~astropy.coordinates.Angle`
+    angle : angle-like
         The amount of rotation the matrices should represent.  Can be an array.
-    axis : str or array_like
+    axis : str or array-like
         Either ``'x'``, ``'y'``, ``'z'``, or a (x,y,z) specifying the axis to
         rotate about. If ``'x'``, ``'y'``, or ``'z'``, the rotation sense is
         counterclockwise looking down the + axis (e.g. positive rotations obey
         left-hand-rule).  If given as an array, the last dimension should be 3;
         it will be broadcast against ``angle``.
-    unit : UnitBase, optional
+    unit : unit-like, optional
         If ``angle`` does not have associated units, they are in this
         unit.  If neither are provided, it is assumed to be degrees.
 
@@ -107,7 +107,7 @@ def angle_axis(matrix):
 
     Parameters
     ----------
-    matrix : array_like
+    matrix : array-like
         A 3 x 3 unitary rotation matrix (or stack of matrices).
 
     Returns
@@ -129,3 +129,77 @@ def angle_axis(matrix):
     angle = np.arctan2(r[..., 0],
                        m[..., 0, 0] + m[..., 1, 1] + m[..., 2, 2] - 1.)
     return Angle(angle, u.radian), -axis / r
+
+
+def is_O3(matrix):
+    """Check whether a matrix is in the length-preserving group O(3).
+
+    Parameters
+    ----------
+    matrix : (..., N, N) array-like
+        Must have attribute ``.shape`` and method ``.swapaxes()`` and not error
+        when using `~numpy.isclose`.
+
+    Returns
+    -------
+    is_o3 : bool or array of bool
+        If the matrix has more than two axes, the O(3) check is performed on
+        slices along the last two axes -- (M, N, N) => (M, ) bool array.
+
+    Notes
+    -----
+    The orthogonal group O(3) preserves lengths, but is not guaranteed to keep
+    orientations. Rotations and reflections are in this group.
+    For more information, see https://en.wikipedia.org/wiki/Orthogonal_group
+
+    """
+    # matrix is in O(3) (rotations, proper and improper).
+    I = np.identity(matrix.shape[-1])
+    is_o3 = np.all(np.isclose(matrix @ matrix.swapaxes(-2, -1), I, atol=1e-15),
+                   axis=(-2, -1))
+
+    return is_o3
+
+
+def is_rotation(matrix, allow_improper=False):
+    """Check whether a matrix is a rotation, proper or improper.
+
+    Parameters
+    ----------
+    matrix : (..., N, N) array-like
+        Must have attribute ``.shape`` and method ``.swapaxes()`` and not error
+        when using `~numpy.isclose` and `~numpy.linalg.det`.
+    allow_improper : bool, optional
+        Whether to restrict check to the SO(3), the group of proper rotations,
+        or also allow improper rotations (with determinant -1).
+        The default (False) is only SO(3).
+
+    Returns
+    -------
+    isrot : bool or array of bool
+        If the matrix has more than two axes, the checks are performed on
+        slices along the last two axes -- (M, N, N) => (M, ) bool array.
+
+    See Also
+    --------
+    `~astopy.coordinates.matrix_utilities.is_O3`
+        For the less restrictive check that a matrix is in the group O(3).
+
+    Notes
+    -----
+    The group SO(3) is the rotation group. It is O(3), with determinant 1.
+    Rotations with determinant -1 are improper rotations, combining both a
+    rotation and a reflection.
+    For more information, see https://en.wikipedia.org/wiki/Orthogonal_group
+
+    """
+    # matrix is in O(3).
+    is_o3 = is_O3(matrix)
+
+    # determinant checks  for rotation (proper and improper)
+    if allow_improper:  # determinant can be +/- 1
+        is_det1 = np.isclose(np.abs(np.linalg.det(matrix)), 1.0)
+    else:  # restrict to SO(3)
+        is_det1 = np.isclose(np.linalg.det(matrix), 1.0)
+
+    return is_o3 & is_det1
