@@ -276,14 +276,13 @@ def test_angle_formatting():
     assert str(angle) == angle.to_string()
 
     res = 'Angle as HMS: 3h36m29.7888s'
-    assert "Angle as HMS: {}".format(angle.to_string(unit=u.hour)) == res
+    assert f"Angle as HMS: {angle.to_string(unit=u.hour)}" == res
 
     res = 'Angle as HMS: 3:36:29.7888'
-    assert "Angle as HMS: {}".format(angle.to_string(unit=u.hour, sep=":")) == res
+    assert f"Angle as HMS: {angle.to_string(unit=u.hour, sep=':')}" == res
 
     res = 'Angle as HMS: 3:36:29.79'
-    assert "Angle as HMS: {}".format(angle.to_string(unit=u.hour, sep=":",
-                                      precision=2)) == res
+    assert f"Angle as HMS: {angle.to_string(unit=u.hour, sep=':', precision=2)}" == res
 
     # Note that you can provide one, two, or three separators passed as a
     # tuple or list
@@ -298,22 +297,20 @@ def test_angle_formatting():
                                                    precision=4)) == res
 
     res = 'Angle as HMS: 3-36-29.7888'
-    assert "Angle as HMS: {}".format(angle.to_string(unit=u.hour, sep="-",
-                                                    precision=4)) == res
+    assert f"Angle as HMS: {angle.to_string(unit=u.hour, sep='-', precision=4)}" == res
 
     res = 'Angle as HMS: 03h36m29.7888s'
-    assert "Angle as HMS: {}".format(angle.to_string(unit=u.hour, precision=4,
-                                                  pad=True)) == res
+    assert f"Angle as HMS: {angle.to_string(unit=u.hour, precision=4, pad=True)}" == res
 
     # Same as above, in degrees
 
     angle = Angle("3 36 29.78880", unit=u.degree)
 
     res = 'Angle as DMS: 3d36m29.7888s'
-    assert "Angle as DMS: {}".format(angle.to_string(unit=u.degree)) == res
+    assert f"Angle as DMS: {angle.to_string(unit=u.degree)}" == res
 
     res = 'Angle as DMS: 3:36:29.7888'
-    assert "Angle as DMS: {}".format(angle.to_string(unit=u.degree, sep=":")) == res
+    assert f"Angle as DMS: {angle.to_string(unit=u.degree, sep=':')}" == res
 
     res = 'Angle as DMS: 3:36:29.79'
     assert "Angle as DMS: {}".format(angle.to_string(unit=u.degree, sep=":",
@@ -340,28 +337,28 @@ def test_angle_formatting():
                                                   pad=True)) == res
 
     res = 'Angle as rad: 0.0629763rad'
-    assert "Angle as rad: {}".format(angle.to_string(unit=u.radian)) == res
+    assert f"Angle as rad: {angle.to_string(unit=u.radian)}" == res
 
     res = 'Angle as rad decimal: 0.0629763'
-    assert "Angle as rad decimal: {}".format(angle.to_string(unit=u.radian, decimal=True)) == res
+    assert f"Angle as rad decimal: {angle.to_string(unit=u.radian, decimal=True)}" == res
 
     # check negative angles
 
     angle = Angle(-1.23456789, unit=u.degree)
     angle2 = Angle(-1.23456789, unit=u.hour)
 
-    assert angle.to_string() == '-1d14m04.4444s'
-    assert angle.to_string(pad=True) == '-01d14m04.4444s'
-    assert angle.to_string(unit=u.hour) == '-0h04m56.2963s'
-    assert angle2.to_string(unit=u.hour, pad=True) == '-01h14m04.4444s'
+    assert angle.to_string() == '-1d14m04.444404s'
+    assert angle.to_string(pad=True) == '-01d14m04.444404s'
+    assert angle.to_string(unit=u.hour) == '-0h04m56.2962936s'
+    assert angle2.to_string(unit=u.hour, pad=True) == '-01h14m04.444404s'
     assert angle.to_string(unit=u.radian, decimal=True) == '-0.0215473'
 
 
 def test_to_string_vector():
     # Regression test for the fact that vectorize doesn't work with Numpy 1.6
-    assert Angle([1./7., 1./7.], unit='deg').to_string()[0] == "0d08m34.2857s"
-    assert Angle([1./7.], unit='deg').to_string()[0] == "0d08m34.2857s"
-    assert Angle(1./7., unit='deg').to_string() == "0d08m34.2857s"
+    assert Angle([1./7., 1./7.], unit='deg').to_string()[0] == "0d08m34.28571429s"
+    assert Angle([1./7.], unit='deg').to_string()[0] == "0d08m34.28571429s"
+    assert Angle(1./7., unit='deg').to_string() == "0d08m34.28571429s"
 
 
 def test_angle_format_roundtripping():
@@ -874,6 +871,13 @@ def test_regression_formatting_negative():
     assert Angle(-1., unit='hour').to_string() == '-1h00m00s'
 
 
+def test_regression_formatting_default_precision():
+    # Regression test for issue #11140
+    assert Angle('10:20:30.12345678d').to_string() == '10d20m30.12345678s'
+    assert Angle('10d20m30.123456784564s').to_string() == '10d20m30.12345678s'
+    assert Angle('10d20m30.123s').to_string() == '10d20m30.123s'
+
+
 def test_empty_sep():
     a = Angle('05h04m31.93830s')
 
@@ -994,7 +998,7 @@ def test_angle_with_cds_units_enabled():
     """
     from astropy.units import cds
     # the problem is with the parser, so remove it temporarily
-    from astropy.coordinates.angle_utilities import _AngleParser
+    from astropy.coordinates.angle_formats import _AngleParser
     del _AngleParser._thread_local._parser
     with cds.enable():
         Angle('5d')
@@ -1012,6 +1016,11 @@ def test_latitude_nan():
     Latitude([0, np.nan, 1] * u.deg)
 
 
+def test_angle_wrap_at_nan():
+    # Check that passing a NaN to Latitude doesn't raise a warning
+    Angle([0, np.nan, 1] * u.deg).wrap_at(180*u.deg)
+
+
 def test_angle_multithreading():
     """
     Regression test for issue #7168
