@@ -5,7 +5,12 @@ distance measures and other cosmology-related calculations.
 See the `Astropy documentation
 <https://docs.astropy.org/en/latest/cosmology/index.html>`_ for more
 detailed usage examples and references.
+
 """
 
+from . import core, funcs, realizations
 from .core import *
 from .funcs import *
+from .realizations import *
+
+__all__ = core.__all__ + realizations.__all__ + funcs.__all__
