@@ -100,9 +100,9 @@ class HTMLInputter(core.BaseInputter):
                 break
         else:
             if isinstance(self.html['table_id'], int):
-                err_descr = 'number {}'.format(self.html['table_id'])
+                err_descr = f"number {self.html['table_id']}"
             else:
-                err_descr = "id '{}'".format(self.html['table_id'])
+                err_descr = f"id '{self.html['table_id']}'"
             raise core.InconsistentTableError(
                 f'ERROR: HTML table {err_descr} not found')
 
@@ -320,6 +320,8 @@ class HTML(core.BaseReader):
     data_class = HTMLData
     inputter_class = HTMLInputter
 
+    max_ndim = 2  # HTML supports writing 2-d columns with shape (n, m)
+
     def __init__(self, htmldict={}):
         """
         Initialize classes for HTML reading and writing.
@@ -344,6 +346,9 @@ class HTML(core.BaseReader):
         """
         Return data in ``table`` converted to HTML as a list of strings.
         """
+        # Check that table has only 1-d or 2-d columns. Above that fails.
+        self._check_multidim_table(table)
+
         cols = list(table.columns.values())
 
         self.data.header.cols = cols
