@@ -516,6 +516,7 @@ class QDP(basic.Basic):
     """Quick and Dandy Plot table.
 
     Example::
+
         ! Initial comment line 1
         ! Initial comment line 2
         READ TERR 1
@@ -536,9 +537,8 @@ class QDP(basic.Basic):
     of ``NO``s. Comments are exclamation marks, and missing values are single
     ``NO`` entries. The delimiter is usually whitespace, more rarely a comma.
     The QDP format differentiates between data and error columns. The table
-    above has commands
+    above has commands::
 
-    ::
         READ TERR 1
         READ SERR 3
 
@@ -572,6 +572,7 @@ class QDP(basic.Basic):
     and leave the name specification to the user.
 
     Example::
+
         >               Extra space
         >                   |
         >                   v
@@ -584,6 +585,7 @@ class QDP(basic.Basic):
     table. The comments of each table will be stored in the ``comments`` meta.
 
     Example::
+
         t = Table.read(example_qdp, format='ascii.qdp', table_id=1, names=['a', 'b', 'c', 'd'])
 
     reads the second table (``table_id=1``) in file ``example.qdp`` containing
@@ -594,9 +596,8 @@ class QDP(basic.Basic):
     in the file, while ``t.meta['comments']`` will contain ``Table 1 comment``
 
     The table can be written to another file, preserving the same information,
-    as
+    as::
 
-    ::
         t.write(test_file, err_specs={'terr': [1], 'serr': [3]})
 
     Note how the ``terr`` and ``serr`` commands are passed to the writer.
