@@ -9,8 +9,8 @@ import fnmatch
 import glob
 import io
 import operator
+import os
 import os.path
-import pathlib
 import textwrap
 
 from collections import defaultdict
@@ -129,7 +129,7 @@ class _BaseDiff:
 
         Parameters
         ----------
-        fileobj : file-like object, string, or None, optional
+        fileobj : file-like, string, or None, optional
             If `None`, this method returns the report as a string. Otherwise it
             returns `None` and writes the report to the given file-like object
             (which must have a ``.write()`` method at a minimum), or to a new
@@ -269,7 +269,7 @@ class FITSDiff(_BaseDiff):
             whitespace (default: True).
         """
 
-        if isinstance(a, (str, pathlib.Path)):
+        if isinstance(a, (str, os.PathLike)):
             try:
                 a = fitsopen(a)
             except Exception as exc:
@@ -279,7 +279,7 @@ class FITSDiff(_BaseDiff):
         else:
             close_a = False
 
-        if isinstance(b, (str, pathlib.Path)):
+        if isinstance(b, (str, os.PathLike)):
             try:
                 b = fitsopen(b)
             except Exception as exc:
@@ -327,13 +327,11 @@ class FITSDiff(_BaseDiff):
         # Record filenames for use later in _report
         self.filenamea = self.a.filename()
         if not self.filenamea:
-            self.filenamea = '<{} object at {:#x}>'.format(
-                self.a.__class__.__name__, id(self.a))
+            self.filenamea = f'<{self.a.__class__.__name__} object at {id(self.a):#x}>'
 
         self.filenameb = self.b.filename()
         if not self.filenameb:
-            self.filenameb = '<{} object at {:#x}>'.format(
-                self.b.__class__.__name__, id(self.b))
+            self.filenameb = f'<{self.b.__class__.__name__} object at {id(self.b):#x}>'
 
         if self.ignore_hdus:
             self.a = HDUList([h for h in self.a if h.name not in self.ignore_hdus])
@@ -371,8 +369,7 @@ class FITSDiff(_BaseDiff):
 
         if self.ignore_hdus:
             ignore_hdus = ' '.join(sorted(self.ignore_hdus))
-            self._writeln(' HDU(s) not to be compared:\n{}'
-                          .format(wrapper.fill(ignore_hdus)))
+            self._writeln(f' HDU(s) not to be compared:\n{wrapper.fill(ignore_hdus)}')
 
         if self.ignore_hdu_patterns:
             ignore_hdu_patterns = ' '.join(sorted(self.ignore_hdu_patterns))
@@ -402,8 +399,8 @@ class FITSDiff(_BaseDiff):
         if self.diff_hdu_count:
             self._fileobj.write('\n')
             self._writeln('Files contain different numbers of HDUs:')
-            self._writeln(' a: {}'.format(self.diff_hdu_count[0]))
-            self._writeln(' b: {}'.format(self.diff_hdu_count[1]))
+            self._writeln(f' a: {self.diff_hdu_count[0]}')
+            self._writeln(f' b: {self.diff_hdu_count[1]}')
 
             if not self.diff_hdus:
                 self._writeln('No differences found between common HDUs.')
@@ -879,28 +876,25 @@ class HeaderDiff(_BaseDiff):
     def _report(self):
         if self.diff_keyword_count:
             self._writeln(' Headers have different number of cards:')
-            self._writeln('  a: {}'.format(self.diff_keyword_count[0]))
-            self._writeln('  b: {}'.format(self.diff_keyword_count[1]))
+            self._writeln(f'  a: {self.diff_keyword_count[0]}')
+            self._writeln(f'  b: {self.diff_keyword_count[1]}')
         if self.diff_keywords:
             for keyword in self.diff_keywords[0]:
                 if keyword in Card._commentary_keywords:
                     val = self.a[keyword][0]
                 else:
                     val = self.a[keyword]
-                self._writeln(' Extra keyword {!r:8} in a: {!r}'.format(
-                                keyword, val))
+                self._writeln(f' Extra keyword {keyword!r:8} in a: {val!r}')
             for keyword in self.diff_keywords[1]:
                 if keyword in Card._commentary_keywords:
                     val = self.b[keyword][0]
                 else:
                     val = self.b[keyword]
-                self._writeln(' Extra keyword {!r:8} in b: {!r}'.format(
-                                keyword, val))
+                self._writeln(f' Extra keyword {keyword!r:8} in b: {val!r}')
 
         if self.diff_duplicate_keywords:
             for keyword, count in sorted(self.diff_duplicate_keywords.items()):
-                self._writeln(' Inconsistent duplicates of keyword {!r:8}:'
-                              .format(keyword))
+                self._writeln(f' Inconsistent duplicates of keyword {keyword!r:8}:')
                 self._writeln('  Occurs {} time(s) in a, {} times in (b)'
                               .format(*count))
 
@@ -1126,8 +1120,8 @@ class RawDataDiff(ImageDataDiff):
     def _report(self):
         if self.diff_dimensions:
             self._writeln(' Data sizes differ:')
-            self._writeln('  a: {} bytes'.format(self.diff_dimensions[0]))
-            self._writeln('  b: {} bytes'.format(self.diff_dimensions[1]))
+            self._writeln(f'  a: {self.diff_dimensions[0]} bytes')
+            self._writeln(f'  b: {self.diff_dimensions[1]} bytes')
             # For now we don't do any further comparison if the dimensions
             # differ; though in the future it might be nice to be able to
             # compare at least where the images intersect
@@ -1408,34 +1402,31 @@ class TableDataDiff(_BaseDiff):
     def _report(self):
         if self.diff_column_count:
             self._writeln(' Tables have different number of columns:')
-            self._writeln('  a: {}'.format(self.diff_column_count[0]))
-            self._writeln('  b: {}'.format(self.diff_column_count[1]))
+            self._writeln(f'  a: {self.diff_column_count[0]}')
+            self._writeln(f'  b: {self.diff_column_count[1]}')
 
         if self.diff_column_names:
             # Show columns with names unique to either table
             for name in self.diff_column_names[0]:
                 format = self.diff_columns[0][name.lower()].format
-                self._writeln(' Extra column {} of format {} in a'.format(
-                                name, format))
+                self._writeln(f' Extra column {name} of format {format} in a')
             for name in self.diff_column_names[1]:
                 format = self.diff_columns[1][name.lower()].format
-                self._writeln(' Extra column {} of format {} in b'.format(
-                                name, format))
+                self._writeln(f' Extra column {name} of format {format} in b')
 
         col_attrs = dict(_COL_ATTRS)
         # Now go through each table again and show columns with common
         # names but other property differences...
         for col_attr, vals in self.diff_column_attributes:
             name, attr = col_attr
-            self._writeln(' Column {} has different {}:'.format(
-                    name, col_attrs[attr]))
+            self._writeln(f' Column {name} has different {col_attrs[attr]}:')
             report_diff_values(vals[0], vals[1], fileobj=self._fileobj,
                                indent_width=self._indent + 1)
 
         if self.diff_rows:
             self._writeln(' Table rows differ:')
-            self._writeln('  a: {}'.format(self.diff_rows[0]))
-            self._writeln('  b: {}'.format(self.diff_rows[1]))
+            self._writeln(f'  a: {self.diff_rows[0]}')
+            self._writeln(f'  b: {self.diff_rows[1]}')
             self._writeln(' No further data comparison performed.')
             return
 
@@ -1474,7 +1465,7 @@ def report_diff_keyword_attr(fileobj, attr, diffs, keyword, ind=0):
             if idx == 0:
                 dup = ''
             else:
-                dup = '[{}]'.format(idx + 1)
+                dup = f'[{idx + 1}]'
             fileobj.write(
                 fixed_width_indent(' Keyword {:8}{} has different {}:\n'
                                    .format(keyword, dup, attr), ind))
