@@ -24,16 +24,19 @@ from astropy.utils.exceptions import AstropyUserWarning
 from astropy.utils.decorators import deprecated_renamed_argument
 
 # NOTE: Python can be built without bz2.
-try:
+from astropy.utils.compat.optional_deps import HAS_BZ2
+if HAS_BZ2:
     import bz2
-except ImportError:
-    HAS_BZ2 = False
-else:
-    HAS_BZ2 = True
+
+__all__ = ["HDUList", "fitsopen"]
+
+# FITS file signature as per RFC 4047
+FITS_SIGNATURE = b'SIMPLE  =                    T'
 
 
 def fitsopen(name, mode='readonly', memmap=None, save_backup=False,
-             cache=True, lazy_load_hdus=None, **kwargs):
+             cache=True, lazy_load_hdus=None, ignore_missing_simple=False,
+             **kwargs):
     """Factory function to open a FITS file and return an `HDUList` object.
 
     Parameters
@@ -91,9 +94,15 @@ def fitsopen(name, mode='readonly', memmap=None, save_backup=False,
         integer convention is assumed.
 
     ignore_missing_end : bool, optional
-        Do not issue an exception when opening a file that is missing an
+        Do not raise an exception when opening a file that is missing an
         ``END`` card in the last header. Default is `False`.
 
+    ignore_missing_simple : bool, optional
+        Do not raise an exception when the SIMPLE keyword is missing.
+        Default is `False`.
+
+        .. versionadded:: 4.2
+
     checksum : bool, str, optional
         If `True`, verifies that both ``DATASUM`` and ``CHECKSUM`` card values
         (when present in the HDU header) match the header and data of all HDU's
@@ -136,8 +145,8 @@ def fitsopen(name, mode='readonly', memmap=None, save_backup=False,
 
     Returns
     -------
-        hdulist : an `HDUList` object
-            `HDUList` containing all of the header data units in the file.
+    hdulist : `HDUList`
+        `HDUList` containing all of the header data units in the file.
 
     """
 
@@ -162,7 +171,7 @@ def fitsopen(name, mode='readonly', memmap=None, save_backup=False,
         raise ValueError(f'Empty filename: {name!r}')
 
     return HDUList.fromfile(name, mode, memmap, save_backup, cache,
-                            lazy_load_hdus, **kwargs)
+                            lazy_load_hdus, ignore_missing_simple, **kwargs)
 
 
 class HDUList(list, _Verify):
@@ -177,11 +186,11 @@ class HDUList(list, _Verify):
 
         Parameters
         ----------
-        hdus : sequence of HDU objects or single HDU, optional
+        hdus : BaseHDU or sequence thereof, optional
             The HDU object(s) to comprise the `HDUList`.  Should be
             instances of HDU classes like `ImageHDU` or `BinTableHDU`.
 
-        file : file object, bytes, optional
+        file : file-like, bytes, optional
             The opened physical file associated with the `HDUList`
             or a bytes object containing the contents of the FITS
             file.
@@ -224,8 +233,7 @@ class HDUList(list, _Verify):
 
         for idx, hdu in enumerate(hdus):
             if not isinstance(hdu, _BaseHDU):
-                raise TypeError("Element {} in the HDUList input is "
-                                "not an HDU.".format(idx))
+                raise TypeError(f"Element {idx} in the HDUList input is not an HDU.")
 
         super().__init__(hdus)
 
@@ -353,8 +361,7 @@ class HDUList(list, _Verify):
         try:
             self._try_while_unread_hdus(super().__setitem__, _key, hdu)
         except IndexError:
-            raise IndexError('Extension {} is out of bound or not found.'
-                             .format(key))
+            raise IndexError(f'Extension {key} is out of bound or not found.')
 
         self._resize = True
         self._truncate = False
@@ -389,7 +396,7 @@ class HDUList(list, _Verify):
     @classmethod
     def fromfile(cls, fileobj, mode=None, memmap=None,
                  save_backup=False, cache=True, lazy_load_hdus=True,
-                 **kwargs):
+                 ignore_missing_simple=False, **kwargs):
         """
         Creates an `HDUList` instance from a file-like object.
 
@@ -400,6 +407,7 @@ class HDUList(list, _Verify):
 
         return cls._readfrom(fileobj=fileobj, mode=mode, memmap=memmap,
                              save_backup=save_backup, cache=cache,
+                             ignore_missing_simple=ignore_missing_simple,
                              lazy_load_hdus=lazy_load_hdus, **kwargs)
 
     @classmethod
@@ -415,11 +423,13 @@ class HDUList(list, _Verify):
 
         Parameters
         ----------
-        data : str, buffer, memoryview, etc.
-            A string or other memory buffer containing an entire FITS file.  It
-            should be noted that if that memory is read-only (such as a Python
-            string) the returned :class:`HDUList`'s data portions will also be
-            read-only.
+        data : str, buffer-like, etc.
+            A string or other memory buffer containing an entire FITS file.
+            Buffer-like objects include :class:`~bytes`, :class:`~bytearray`,
+            :class:`~memoryview`, and :class:`~numpy.ndarray`.
+            It should be noted that if that memory is read-only (such as a
+            Python string) the returned :class:`HDUList`'s data portions will
+            also be read-only.
 
         kwargs : dict
             Optional keyword arguments.  See
@@ -554,7 +564,7 @@ class HDUList(list, _Verify):
 
         Returns
         -------
-        hdu : HDU object
+        hdu : BaseHDU
             The HDU object at position indicated by ``index`` or having name
             and version specified by ``index``.
         """
@@ -573,7 +583,7 @@ class HDUList(list, _Verify):
         index : int
             Index before which to insert the new HDU.
 
-        hdu : HDU object
+        hdu : BaseHDU
             The HDU object to insert
         """
 
@@ -635,7 +645,7 @@ class HDUList(list, _Verify):
 
         Parameters
         ----------
-        hdu : HDU object
+        hdu : BaseHDU
             HDU to add to the `HDUList`.
         """
 
@@ -682,7 +692,7 @@ class HDUList(list, _Verify):
 
         Parameters
         ----------
-        key : int, str, tuple of (string, int) or an HDU object
+        key : int, str, tuple of (string, int) or BaseHDU
            The key identifying the HDU.  If ``key`` is a tuple, it is of the
            form ``(name, ver)`` where ``ver`` is an ``EXTVER`` value that must
            match the HDU being searched for.
@@ -985,7 +995,7 @@ class HDUList(list, _Verify):
 
         Parameters
         ----------
-        output : file, bool, optional
+        output : file-like or bool, optional
             A file-like object to write the output to.  If `False`, does not
             output to a file and instead returns a list of tuples representing
             the HDU info.  Writes to ``sys.stdout`` by default.
@@ -1028,9 +1038,10 @@ class HDUList(list, _Verify):
 
         Returns
         -------
-        filename : a string containing the file name associated with the
-                   HDUList object if an association exists.  Otherwise returns
-                   None.
+        filename : str
+            A string containing the file name associated with the HDUList
+            object if an association exists.  Otherwise returns None.
+
         """
         if self._file is not None:
             if hasattr(self._file, 'name'):
@@ -1039,7 +1050,8 @@ class HDUList(list, _Verify):
 
     @classmethod
     def _readfrom(cls, fileobj=None, data=None, mode=None, memmap=None,
-                  cache=True, lazy_load_hdus=True, **kwargs):
+                  cache=True, lazy_load_hdus=True, ignore_missing_simple=False,
+                  **kwargs):
         """
         Provides the implementations from HDUList.fromfile and
         HDUList.fromstring, both of which wrap this method, as their
@@ -1065,6 +1077,21 @@ class HDUList(list, _Verify):
             # fromstring case; the data type of ``data`` will be checked in the
             # _BaseHDU.fromstring call.
 
+        if (hdulist._file and hdulist._file.mode != 'ostream' and
+                hdulist._file.size > 0):
+            pos = hdulist._file.tell()
+            simple = hdulist._file.read(30)
+            match_sig = (simple[:-1] == FITS_SIGNATURE[:-1] and
+                         simple[-1:] in (b'T', b'F'))
+
+            if not match_sig and not ignore_missing_simple:
+                if hdulist._file.close_on_error:
+                    hdulist._file.close()
+                raise OSError('No SIMPLE card found, this file does not '
+                              'appear to be a valid FITS file')
+
+            hdulist._file.seek(pos)
+
         # Store additional keyword args that were passed to fits.open
         hdulist._open_kwargs = kwargs
 
@@ -1235,8 +1262,7 @@ class HDUList(list, _Verify):
         # each element calls their own verify
         for idx, hdu in enumerate(self):
             if idx > 0 and (not isinstance(hdu, ExtensionHDU)):
-                err_text = ("HDUList's element {} is not an "
-                            "extension HDU.".format(str(idx)))
+                err_text = f"HDUList's element {str(idx)} is not an extension HDU."
 
                 err = self.run_option(option, err_text=err_text, fixable=False)
                 errs.append(err)
