@@ -10,9 +10,11 @@ import subprocess
 import pytest
 import numpy as np
 
+from astropy.io.fits.hdu.base import _ValidHDU, _NonstandardHDU
 from astropy.io.fits.verify import VerifyError, VerifyWarning
 from astropy.io import fits
 from astropy.utils.exceptions import AstropyUserWarning, AstropyDeprecationWarning
+from astropy.utils.data import get_pkg_data_filenames
 
 from . import FitsTestCase
 
@@ -744,13 +746,14 @@ class TestHDUListFunctions(FitsTestCase):
                         np.testing.assert_array_equal(hdul[idx].data,
                                                       hdul2[idx].data)
 
-        for filename in glob.glob(os.path.join(self.data_dir, '*.fits')):
-            if sys.platform == 'win32' and filename == 'zerowidth.fits':
+        for filename in get_pkg_data_filenames('data', pattern='*.fits'):
+            if sys.platform == 'win32' and filename.endswith('zerowidth.fits'):
                 # Running this test on this file causes a crash in some
                 # versions of Numpy on Windows.  See ticket:
                 # https://aeon.stsci.edu/ssb/trac/pyfits/ticket/174
                 continue
-            elif filename.endswith('variable_length_table.fits'):
+            elif filename.endswith(('variable_length_table.fits',
+                                    'theap-gap.fits')):
                 # Comparing variable length arrays is non-trivial and thus
                 # skipped at this point.
                 # TODO: That's probably possible, so one could make it work.
@@ -949,6 +952,71 @@ class TestHDUListFunctions(FitsTestCase):
         assert len(read_exts) == 2
         f.close()
 
+    def test_read_non_standard_hdu(self):
+        filename = self.temp('bad-fits.fits')
+        hdu = fits.PrimaryHDU()
+        hdu.header['FOO'] = 'BAR'
+        buf = io.BytesIO()
+        hdu.writeto(buf)
+        buf.seek(0)
+        hdustr = buf.read()
+        hdustr = hdustr.replace(b'SIMPLE  =                    T',
+                                b'SIMPLE  =                    F')
+        with open(filename, mode='wb') as f:
+            f.write(hdustr)
+
+        with fits.open(filename) as hdul:
+            assert isinstance(hdul[0], _NonstandardHDU)
+            assert hdul[0].header['FOO'] == 'BAR'
+
+    def test_proper_error_raised_on_non_fits_file(self):
+        filename = self.temp('not-fits.fits')
+        with open(filename, mode='w', encoding='utf=8') as f:
+            f.write('Not a FITS file')
+
+        match = ('No SIMPLE card found, this file '
+                 'does not appear to be a valid FITS file')
+
+        # This should raise an OSError because there is no end card.
+        with pytest.raises(OSError, match=match):
+            fits.open(filename)
+
+        with pytest.raises(OSError, match=match):
+            fits.open(filename, mode='append')
+
+        with pytest.raises(OSError, match=match):
+            fits.open(filename, mode='update')
+
+    def test_proper_error_raised_on_invalid_fits_file(self):
+        filename = self.temp('bad-fits.fits')
+        hdu = fits.PrimaryHDU()
+        hdu.header['FOO'] = 'BAR'
+        buf = io.BytesIO()
+        hdu.writeto(buf)
+        # write 80 additional bytes so the block will have the correct size
+        buf.write(b' '*80)
+        buf.seek(0)
+        buf.seek(80)  # now remove the SIMPLE card
+        with open(filename, mode='wb') as f:
+            f.write(buf.read())
+
+        match = ('No SIMPLE card found, this file '
+                 'does not appear to be a valid FITS file')
+
+        # This should raise an OSError because there is no end card.
+        with pytest.raises(OSError, match=match):
+            fits.open(filename)
+
+        with pytest.raises(OSError, match=match):
+            fits.open(filename, mode='append')
+
+        with pytest.raises(OSError, match=match):
+            fits.open(filename, mode='update')
+
+        with fits.open(filename, ignore_missing_simple=True) as hdul:
+            assert isinstance(hdul[0], _ValidHDU)
+            assert hdul[0].header['FOO'] == 'BAR'
+
     def test_proper_error_raised_on_non_fits_file_with_unicode(self):
         """
         Regression test for https://github.com/astropy/astropy/issues/5594
@@ -957,16 +1025,14 @@ class TestHDUListFunctions(FitsTestCase):
         with unicode content that is not actually a FITS file. See:
         https://github.com/astropy/astropy/issues/5594#issuecomment-266583218
         """
-        import codecs
         filename = self.temp('not-fits-with-unicode.fits')
-        with codecs.open(filename, mode='w', encoding='utf=8') as f:
+        with open(filename, mode='w', encoding='utf=8') as f:
             f.write('Ce\xe7i ne marche pas')
 
         # This should raise an OSError because there is no end card.
-        with pytest.raises(OSError):
-            with pytest.warns(AstropyUserWarning, match=r'non-ASCII characters '
-                              r'are present in the FITS file header'):
-                fits.open(filename)
+        with pytest.raises(OSError, match='No SIMPLE card found, this file '
+                           'does not appear to be a valid FITS file'):
+            fits.open(filename)
 
     def test_no_resource_warning_raised_on_non_fits_file(self):
         """
@@ -995,7 +1061,7 @@ class TestHDUListFunctions(FitsTestCase):
 
         # Make sure that files opened by the user are not closed
         with open(filename, mode='rb') as f:
-            with pytest.raises(OSError), pytest.warns(VerifyWarning):
+            with pytest.raises(OSError):
                 fits.open(f, ignore_missing_end=False)
 
             assert not f.closed
@@ -1006,7 +1072,7 @@ class TestHDUListFunctions(FitsTestCase):
 
             assert not f.closed
 
-        with pytest.raises(OSError), pytest.warns(VerifyWarning):
+        with pytest.raises(OSError):
             fits.open(filename, ignore_missing_end=False)
 
         with pytest.raises(OSError), pytest.warns(VerifyWarning):
