@@ -3,6 +3,7 @@
 import os
 from copy import copy
 from io import StringIO
+from collections import Counter
 
 import pytest
 import numpy as np
@@ -13,6 +14,7 @@ from astropy.table import Table
 from astropy.utils.compat.context import nullcontext
 from astropy.utils.exceptions import AstropyUserWarning
 from astropy import units as u
+from astropy.utils.compat.optional_deps import HAS_YAML
 
 # Since we reset the readers/writers below, we need to also import any
 # sub-package that defines readers/writers first
@@ -26,12 +28,6 @@ from astropy import timeseries  # noqa
 # This leaves the registry corrupted.
 ORIGINAL = {}
 
-try:
-    import yaml  # pylint: disable=W0611 # noqa
-    HAS_YAML = True
-except ImportError:
-    HAS_YAML = False
-
 
 class TestData:
     read = classmethod(io_registry.read)
@@ -257,7 +253,9 @@ def test_read_toomanyformats():
     io_registry.register_identifier('test2', TestData, lambda o, *x, **y: True)
     with pytest.raises(io_registry.IORegistryError) as exc:
         TestData.read()
-    assert str(exc.value) == "Format is ambiguous - options are: test1, test2"
+    assert str(exc.value) == (
+        "Format is ambiguous - options are: test1, test2"
+    )
 
 
 def test_write_toomanyformats():
@@ -265,7 +263,49 @@ def test_write_toomanyformats():
     io_registry.register_identifier('test2', TestData, lambda o, *x, **y: True)
     with pytest.raises(io_registry.IORegistryError) as exc:
         TestData().write()
-    assert str(exc.value) == "Format is ambiguous - options are: test1, test2"
+    assert str(exc.value) == (
+        "Format is ambiguous - options are: test1, test2"
+    )
+
+
+def test_read_uses_priority():
+    counter = Counter()
+
+    def counting_reader1(*args, **kwargs):
+        counter["test1"] += 1
+        return TestData()
+
+    def counting_reader2(*args, **kwargs):
+        counter["test2"] += 1
+        return TestData()
+
+    io_registry.register_reader('test1', TestData, counting_reader1, priority=1)
+    io_registry.register_reader('test2', TestData, counting_reader2, priority=2)
+    io_registry.register_identifier('test1', TestData, lambda o, *x, **y: True)
+    io_registry.register_identifier('test2', TestData, lambda o, *x, **y: True)
+
+    TestData.read()
+    assert counter["test2"] == 1
+    assert counter["test1"] == 0
+
+
+def test_write_uses_priority():
+    counter = Counter()
+
+    def counting_writer1(*args, **kwargs):
+        counter["test1"] += 1
+
+    def counting_writer2(*args, **kwargs):
+        counter["test2"] += 1
+
+    io_registry.register_writer('test1', TestData, counting_writer1, priority=1)
+    io_registry.register_writer('test2', TestData, counting_writer2, priority=2)
+    io_registry.register_identifier('test1', TestData, lambda o, *x, **y: True)
+    io_registry.register_identifier('test2', TestData, lambda o, *x, **y: True)
+
+    TestData().write()
+    assert counter["test2"] == 1
+    assert counter["test1"] == 0
 
 
 def test_read_format_noreader():
