@@ -69,7 +69,7 @@ def _format_message(message, name, config=None, pos=None):
     if pos is None:
         pos = ('?', '?')
     filename = config.get('filename', '?')
-    return '{}:{}:{}: {}: {}'.format(filename, pos[0], pos[1], name, message)
+    return f'{filename}:{pos[0]}:{pos[1]}: {name}: {message}'
 
 
 def _suppressed_warning(warning, config, stacklevel=2):
@@ -167,8 +167,7 @@ def parse_vowarning(line):
             result['is_warning'] = (warning[0].upper() == 'W')
             result['is_exception'] = not result['is_warning']
             result['number'] = int(match.group('warning')[1:])
-            result['doc_url'] = "io/votable/api_exceptions.html#{}".format(
-                warning.lower())
+            result['doc_url'] = f"io/votable/api_exceptions.html#{warning.lower()}"
         else:
             result['is_warning'] = False
             result['is_exception'] = False
@@ -1040,9 +1039,10 @@ class W49(VOTableSpecWarning):
 
 class W50(VOTableSpecWarning):
     """
-    Invalid unit string as defined in the `Standards for Astronomical
-    Catalogues, Version 2.0
-    <http://cdsarc.u-strasbg.fr/doc/catstd-3.2.htx>`_.
+    Invalid unit string as defined in the `Units in the VO, Version 1.0
+    <https://www.ivoa.net/documents/VOUnits>`_ (VOTable version >= 1.4)
+    or `Standards for Astronomical Catalogues, Version 2.0
+    <http://cdsarc.u-strasbg.fr/doc/catstd-3.2.htx>`_ (version < 1.4).
 
     Consider passing an explicit ``unit_format`` parameter if the units
     in this file conform to another specification.
@@ -1509,7 +1509,7 @@ def _build_doc_string():
 
         for name, cls in classes:
             out.write(f".. _{name}:\n\n")
-            msg = "{}: {}".format(cls.__name__, cls.get_short_name())
+            msg = f"{cls.__name__}: {cls.get_short_name()}"
             if not isinstance(msg, str):
                 msg = msg.decode('utf-8')
             out.write(msg)
