@@ -7,12 +7,7 @@ from numpy.testing import assert_allclose, assert_array_equal
 from astropy.modeling.fitting import LevMarLSQFitter
 from astropy.modeling.models import Shift, Rotation2D, Gaussian1D, Identity, Mapping
 from astropy.utils import NumpyRNGContext
-
-try:
-    from scipy import optimize  # pylint: disable=W0611
-    HAS_SCIPY = True
-except ImportError:
-    HAS_SCIPY = False
+from astropy.utils.compat.optional_deps import HAS_SCIPY  # noqa
 
 
 def test_swap_axes():
