@@ -16,17 +16,11 @@ from astropy.modeling.models import Gaussian2D
 from astropy.modeling.core import FittableModel
 from astropy.modeling.parameters import Parameter
 from astropy.modeling.polynomial import PolynomialBase
-from astropy.utils import minversion
 from astropy.tests.helper import assert_quantity_allclose
 from astropy.utils import NumpyRNGContext
+from astropy.utils.compat.optional_deps import HAS_SCIPY  # noqa
 from .example_models import models_1D, models_2D
 
-try:
-    import scipy
-    HAS_SCIPY = True
-except ImportError:
-    HAS_SCIPY = False
-
 
 @pytest.mark.skipif('not HAS_SCIPY')
 def test_custom_model(amplitude=4, frequency=1):
@@ -98,8 +92,8 @@ def test_inconsistent_input_shapes():
     # but not array broadcasting
     x.shape = (10, 1)
     y.shape = (1, 10)
-    with pytest.raises(ValueError):
-        g(x, y)
+    result = g(x, y)
+    assert result.shape == (10, 10)
 
 
 def test_custom_model_bounding_box():
@@ -294,9 +288,9 @@ class Fittable2DModelTester:
                                  use_constraints=False)
 
         # add 10% noise to the amplitude
-        rsn = np.random.RandomState(1234567890)
+        rsn = np.random.default_rng(0)
         amplitude = test_parameters['parameters'][0]
-        n = 0.1 * amplitude * (rsn.rand(self.M, self.N) - 0.5)
+        n = 0.1 * amplitude * (rsn.random((self.M, self.N)) - 0.5)
 
         data = model(xv, yv) + n
         fitter_with_deriv = fitting.LevMarLSQFitter()
@@ -452,9 +446,31 @@ class Fittable1DModelTester:
         model_no_deriv = create_model(model_class, test_parameters,
                                       use_constraints=False)
 
+        # NOTE: PR 10644 replaced deprecated usage of RandomState but could not
+        #       find a new seed that did not cause test failure, resorted to hardcoding.
         # add 10% noise to the amplitude
-        rsn = np.random.RandomState(1234567890)
-        n = 0.1 * parameters[0] * (rsn.rand(self.N) - 0.5)
+        rsn_rand_1234567890 = np.array([
+            0.61879477, 0.59162363, 0.88868359, 0.89165480, 0.45756748,
+            0.77818808, 0.26706377, 0.99610621, 0.54009489, 0.53752161,
+            0.40099938, 0.70540579, 0.40518559, 0.94999075, 0.03075388,
+            0.13602495, 0.08297726, 0.42352224, 0.23449723, 0.74743526,
+            0.65177865, 0.68998682, 0.16413419, 0.87642114, 0.44733314,
+            0.57871104, 0.52377835, 0.62689056, 0.34869427, 0.26209748,
+            0.07498055, 0.17940570, 0.82999425, 0.98759822, 0.11326099,
+            0.63846415, 0.73056694, 0.88321124, 0.52721004, 0.66487673,
+            0.74209309, 0.94083846, 0.70123128, 0.29534353, 0.76134369,
+            0.77593881, 0.36985514, 0.89519067, 0.33082813, 0.86108824,
+            0.76897859, 0.61343376, 0.43870907, 0.91913538, 0.76958966,
+            0.51063556, 0.04443249, 0.57463611, 0.31382006, 0.41221713,
+            0.21531811, 0.03237521, 0.04166386, 0.73109303, 0.74556052,
+            0.64716325, 0.77575353, 0.64599254, 0.16885816, 0.48485480,
+            0.53844248, 0.99690349, 0.23657074, 0.04119088, 0.46501519,
+            0.35739006, 0.23002665, 0.53420791, 0.71639475, 0.81857486,
+            0.73994342, 0.07948837, 0.75688276, 0.13240193, 0.48465576,
+            0.20624753, 0.02298276, 0.54257873, 0.68123230, 0.35887468,
+            0.36296147, 0.67368397, 0.29505730, 0.66558885, 0.93652252,
+            0.36755130, 0.91787687, 0.75922703, 0.48668067, 0.45967890])
+        n = 0.1 * parameters[0] * (rsn_rand_1234567890 - 0.5)
 
         data = model_with_deriv(x) + n
         fitter_with_deriv = fitting.LevMarLSQFitter()
@@ -790,4 +806,4 @@ def test_parameter_inheritance():
     assert b.param_names == ('f', 'x', 'y', 'h')
     assert b.h == 5
     assert b.f == 3
-    assert b.f.fixed == True
+    assert b.f.fixed == True  # noqa: E712
