@@ -435,7 +435,7 @@ def generic_recursive_equality_test(a, b, class_history):
     Check if the attributes of a and b are equal. Then,
     check if the attributes of the attributes are equal.
     """
-    dict_a = a.__dict__
+    dict_a = a.__getstate__() if hasattr(a, '__getstate__') else a.__dict__
     dict_b = b.__dict__
     for key in dict_a:
         assert key in dict_b,\
