@@ -168,7 +168,7 @@ class QuantityInfo(QuantityInfoBase):
 
         Returns
         -------
-        col : Quantity (or subclass)
+        col : `~astropy.units.Quantity` (or subclass)
             Empty instance of this class consistent with ``cols``
 
         """
@@ -217,14 +217,14 @@ class Quantity(np.ndarray):
 
     Parameters
     ----------
-    value : number, `~numpy.ndarray`, `Quantity` object (sequence), str
+    value : number, `~numpy.ndarray`, `~astropy.units.Quantity` (sequence), or str
         The numerical value of this quantity in the units given by unit.  If a
         `Quantity` or sequence of them (or any other valid object with a
         ``unit`` attribute), creates a new `Quantity` object, converting to
         `unit` units as needed.  If a string, it is converted to a number or
         `Quantity`, depending on whether a unit is present.
 
-    unit : `~astropy.units.UnitBase` instance, str
+    unit : unit-like
         An object that represents the unit associated with the input value.
         Must be an `~astropy.units.UnitBase` object or a string parseable by
         the :mod:`~astropy.units` package.
@@ -272,6 +272,8 @@ class Quantity(np.ndarray):
     Quantities can also be created by multiplying a number or array with a
     :class:`~astropy.units.Unit`. See https://docs.astropy.org/en/latest/units/
 
+    Unless the ``dtype`` argument is explicitly specified, integer
+    or (non-Quantity) object inputs are converted to `float` by default.
     """
     # Need to set a class-level default for _equivalencies, or
     # Constants can not initialize properly
@@ -373,7 +375,7 @@ class Quantity(np.ndarray):
                     copy = False  # copy will be made in conversion at end
 
         value = np.array(value, dtype=dtype, copy=copy, order=order,
-                         subok=False, ndmin=ndmin)
+                         subok=True, ndmin=ndmin)
 
         # check that array contains numbers or long int objects
         if (value.dtype.kind in 'OSU' and
@@ -402,6 +404,13 @@ class Quantity(np.ndarray):
             return value.to(unit)
 
     def __array_finalize__(self, obj):
+        # Check whether super().__array_finalize should be called
+        # (sadly, ndarray.__array_finalize__ is None; we cannot be sure
+        # what is above us).
+        super_array_finalize = super().__array_finalize__
+        if super_array_finalize is not None:
+            super_array_finalize(obj)
+
         # If we're a new object or viewing an ndarray, nothing has to be done.
         if obj is None or obj.__class__ is np.ndarray:
             return
@@ -494,7 +503,7 @@ class Quantity(np.ndarray):
 
         Parameters
         ----------
-        result : `~numpy.ndarray` or tuple of `~numpy.ndarray`
+        result : ndarray or tuple thereof
             Array(s) which need to be turned into quantity.
         unit : `~astropy.units.Unit`
             Unit for the quantities to be returned (or `None` if the result
@@ -539,7 +548,7 @@ class Quantity(np.ndarray):
         Returns
         -------
         tuple :
-            - `Quantity` subclass
+            - `~astropy.units.Quantity` subclass
             - bool: True if subclasses of the given class are ok
         """
         return Quantity, True
@@ -563,14 +572,14 @@ class Quantity(np.ndarray):
             it will be converted to an array scalar.  By default, ``self``
             is converted.
 
-        unit : `UnitBase`, or anything convertible to a :class:`~astropy.units.Unit`, optional
+        unit : unit-like, optional
             The unit of the resulting object.  It is used to select a
             subclass, and explicitly assigned to the view if given.
             If not given, the subclass and unit will be that of ``self``.
 
         Returns
         -------
-        view : Quantity subclass
+        view : `~astropy.units.Quantity` subclass
         """
         # Determine the unit and quantity subclass that we need for the view.
         if unit is None:
@@ -600,7 +609,7 @@ class Quantity(np.ndarray):
         if obj is None:
             obj = self.view(np.ndarray)
         else:
-            obj = np.array(obj, copy=False)
+            obj = np.array(obj, copy=False, subok=True)
 
         # Take the view, set the unit, and update possible other properties
         # such as ``info``, ``wrap_angle`` in `Longitude`, etc.
@@ -666,12 +675,12 @@ class Quantity(np.ndarray):
 
         Parameters
         ----------
-        unit : `~astropy.units.UnitBase` instance, str
+        unit : unit-like
             An object that represents the unit to convert to. Must be
             an `~astropy.units.UnitBase` object or a string parseable
             by the `~astropy.units` package.
 
-        equivalencies : list of equivalence pairs, optional
+        equivalencies : list of tuple
             A list of equivalence pairs to try if the units are not
             directly convertible.  See :ref:`unit_equivalencies`.
             If not provided or ``[]``, class default equivalencies will be used
@@ -705,11 +714,11 @@ class Quantity(np.ndarray):
 
         Parameters
         ----------
-        unit : `~astropy.units.UnitBase` instance or str, optional
+        unit : unit-like, optional
             The unit in which the value should be given. If not given or `None`,
             use the current unit.
 
-        equivalencies : list of equivalence pairs, optional
+        equivalencies : list of tuple, optional
             A list of equivalence pairs to try if the units are not directly
             convertible (see :ref:`unit_equivalencies`). If not provided or
             ``[]``, class default equivalencies will be used (none for
@@ -719,7 +728,7 @@ class Quantity(np.ndarray):
 
         Returns
         -------
-        value : `~numpy.ndarray` or scalar
+        value : ndarray or scalar
             The value in the units specified. For arrays, this will be a view
             of the data if no unit conversion was necessary.
 
@@ -837,9 +846,7 @@ class Quantity(np.ndarray):
         """
         if not self._include_easy_conversion_members:
             raise AttributeError(
-                "'{}' object has no '{}' member".format(
-                    self.__class__.__name__,
-                    attr))
+                f"'{self.__class__.__name__}' object has no '{attr}' member")
 
         def get_virtual_unit_attribute():
             registry = get_current_unit_registry().registry
@@ -857,8 +864,7 @@ class Quantity(np.ndarray):
 
         if value is None:
             raise AttributeError(
-                "{} instance has no attribute '{}'".format(
-                    self.__class__.__name__, attr))
+                f"{self.__class__.__name__} instance has no attribute '{attr}'")
         else:
             return value
 
@@ -1129,11 +1135,11 @@ class Quantity(np.ndarray):
 
         Parameters
         ----------
-        unit : `~astropy.units.UnitBase`, optional
+        unit : unit-like, optional
             Specifies the unit.  If not provided,
             the unit used to initialize the quantity will be used.
 
-        precision : numeric, optional
+        precision : number, optional
             The level of decimal precision. If `None`, or not provided,
             it will be determined from NumPy print options.
 
@@ -1153,7 +1159,7 @@ class Quantity(np.ndarray):
 
         Returns
         -------
-        lstr
+        str
             A string with the contents of this Quantity
         """
         if unit is not None and unit != self.unit:
@@ -1172,16 +1178,21 @@ class Quantity(np.ndarray):
         if format not in formats:
             raise ValueError(f"Unknown format '{format}'")
         elif format is None:
-            return f'{self.value}{self._unitstr:s}'
+            if precision is None:
+                # Use default formatting settings
+                return f'{self.value}{self._unitstr:s}'
+            else:
+                # np.array2string properly formats arrays as well as scalars
+                return np.array2string(self.value, precision=precision, floatmode="fixed") + self._unitstr
 
         # else, for the moment we assume format="latex"
 
         # need to do try/finally because "threshold" cannot be overridden
         # with array2string
-        pops = np.get_printoptions()
 
-        format_spec = '.{}g'.format(
-            precision if precision is not None else pops['precision'])
+        # Set the precision if set, otherwise use numpy default
+        pops = np.get_printoptions()
+        format_spec = f".{precision if precision is not None else pops['precision']}g"
 
         def float_formatter(value):
             return Latex.format_exponential_notation(value,
@@ -1271,7 +1282,7 @@ class Quantity(np.ndarray):
 
         Parameters
         ----------
-        bases : sequence of UnitBase, optional
+        bases : sequence of `~astropy.units.UnitBase`, optional
             The bases to decompose into.  When not provided,
             decomposes down to any irreducible units.  When provided,
             the decomposed result will only contain the given units.
@@ -1328,6 +1339,12 @@ class Quantity(np.ndarray):
     # https://numpy.org/doc/stable/reference/arrays.ndarray.html#array-conversion
 
     def item(self, *args):
+        """Copy an element of an array to a scalar Quantity and return it.
+
+        Like :meth:`~numpy.ndarray.item` except that it always
+        returns a `Quantity`, not a Python scalar.
+
+        """
         return self._new_view(super().item(*args))
 
     def tolist(self):
@@ -1338,22 +1355,21 @@ class Quantity(np.ndarray):
         try:
             _value = value.to_value(self.unit)
         except AttributeError:
-            # We're not a Quantity, so let's try a more general conversion.
+            # We're not a Quantity.
+            # First remove two special cases (with a fast test):
+            # 1) Maybe masked printing? MaskedArray with quantities does not
+            # work very well, but no reason to break even repr and str.
+            # 2) np.ma.masked? useful if we're a MaskedQuantity.
+            if (value is np.ma.masked
+                or (value is np.ma.masked_print_option
+                    and self.dtype.kind == 'O')):
+                return value
+            # Now, let's try a more general conversion.
             # Plain arrays will be converted to dimensionless in the process,
             # but anything with a unit attribute will use that.
             try:
                 as_quantity = Quantity(value)
                 _value = as_quantity.to_value(self.unit)
-            except TypeError:
-                # Could not make a Quantity.  Maybe masked printing?
-                # Note: masked quantities do not work very well, but no reason
-                # to break even repr and str.
-                if (value is np.ma.masked_print_option and
-                        self.dtype.kind == 'O'):
-                    return value
-                else:
-                    raise
-
             except UnitsError:
                 # last chance: if this was not something with a unit
                 # and is all 0, inf, or nan, we treat it as arbitrary unit.
@@ -1363,12 +1379,12 @@ class Quantity(np.ndarray):
                 else:
                     raise
 
-        if check_precision:
-            # If, e.g., we are casting double to float, we want to fail if
+        if self.dtype.kind == 'i' and check_precision:
+            # If, e.g., we are casting float to int, we want to fail if
             # precision is lost, but let things pass if it works.
-            _value = np.array(_value, copy=False)
+            _value = np.array(_value, copy=False, subok=True)
             if not np.can_cast(_value.dtype, self.dtype):
-                self_dtype_array = np.array(_value, self.dtype)
+                self_dtype_array = np.array(_value, self.dtype, subok=True)
                 if not np.all(np.logical_or(self_dtype_array == _value,
                                             np.isnan(_value))):
                     raise TypeError("cannot convert value type to array type "
@@ -1611,15 +1627,18 @@ class Quantity(np.ndarray):
         return self._wrap_function(np.trace, offset, axis1, axis2, dtype,
                                    out=out)
 
-    def var(self, axis=None, dtype=None, out=None, ddof=0):
+    def var(self, axis=None, dtype=None, out=None, ddof=0, keepdims=False):
         return self._wrap_function(np.var, axis, dtype,
-                                   out=out, ddof=ddof, unit=self.unit**2)
+                                   out=out, ddof=ddof, keepdims=keepdims,
+                                   unit=self.unit**2)
 
-    def std(self, axis=None, dtype=None, out=None, ddof=0):
-        return self._wrap_function(np.std, axis, dtype, out=out, ddof=ddof)
+    def std(self, axis=None, dtype=None, out=None, ddof=0, keepdims=False):
+        return self._wrap_function(np.std, axis, dtype, out=out, ddof=ddof,
+                                   keepdims=keepdims)
 
-    def mean(self, axis=None, dtype=None, out=None):
-        return self._wrap_function(np.mean, axis, dtype, out=out)
+    def mean(self, axis=None, dtype=None, out=None, keepdims=False):
+        return self._wrap_function(np.mean, axis, dtype, out=out,
+                                   keepdims=keepdims)
 
     def round(self, decimals=0, out=None):
         return self._wrap_function(np.round, decimals, out=out)
@@ -1659,10 +1678,10 @@ class Quantity(np.ndarray):
 
         Parameters
         ----------
-        obj : int, slice or sequence of ints
+        obj : int, slice or sequence of int
             Object that defines the index or indices before which ``values`` is
             inserted.
-        values : array_like
+        values : array-like
             Values to insert.  If the type of ``values`` is different
             from that of quantity, ``values`` is converted to the matching type.
             ``values`` should be shaped so that it can be broadcast appropriately
@@ -1749,13 +1768,13 @@ def isclose(a, b, rtol=1.e-5, atol=None, equal_nan=False, **kwargs):
 
     Parameters
     ----------
-    a, b : array_like or :class:`~astropy.units.Quantity`
+    a, b : array-like or `~astropy.units.Quantity`
         Input values or arrays to compare
-    rtol : array_like or dimensionless :class:`~astropy.units.Quantity`
+    rtol : array-like or `~astropy.units.Quantity`
         The relative tolerance for the comparison, which defaults to
         ``1e-5``.  If ``rtol`` is a :class:`~astropy.units.Quantity`,
         then it must be dimensionless.
-    atol : number or :class:`~astropy.units.Quantity`
+    atol : number or `~astropy.units.Quantity`
         The absolute tolerance for the comparison.  The units (or lack
         thereof) of ``a``, ``b``, and ``atol`` must be consistent with
         each other.  If `None`, ``atol`` defaults to zero in the
@@ -1775,7 +1794,7 @@ def isclose(a, b, rtol=1.e-5, atol=None, equal_nan=False, **kwargs):
 
     Raises
     ------
-    UnitsError
+    `~astropy.units.UnitsError`
         If the dimensions of ``a``, ``b``, or ``atol`` are incompatible,
         or if ``rtol`` is not dimensionless.
 
@@ -1793,13 +1812,13 @@ def allclose(a, b, rtol=1.e-5, atol=None, equal_nan=False, **kwargs) -> bool:
 
     Parameters
     ----------
-    a, b : array_like or :class:`~astropy.units.Quantity`
+    a, b : array-like or `~astropy.units.Quantity`
         Input values or arrays to compare
-    rtol : array_like or dimensionless :class:`~astropy.units.Quantity`
+    rtol : array-like or `~astropy.units.Quantity`
         The relative tolerance for the comparison, which defaults to
         ``1e-5``.  If ``rtol`` is a :class:`~astropy.units.Quantity`,
         then it must be dimensionless.
-    atol : number or :class:`~astropy.units.Quantity`
+    atol : number or `~astropy.units.Quantity`
         The absolute tolerance for the comparison.  The units (or lack
         thereof) of ``a``, ``b``, and ``atol`` must be consistent with
         each other.  If `None`, ``atol`` defaults to zero in the
@@ -1819,7 +1838,7 @@ def allclose(a, b, rtol=1.e-5, atol=None, equal_nan=False, **kwargs) -> bool:
 
     Raises
     ------
-    UnitsError
+    `~astropy.units.UnitsError`
         If the dimensions of ``a``, ``b``, or ``atol`` are incompatible,
         or if ``rtol`` is not dimensionless.
 
