@@ -6,13 +6,14 @@ import atexit
 import contextlib
 import errno
 import fnmatch
+import functools
 import hashlib
 import os
 import io
-import pathlib
 import re
 import shutil
 import socket
+import ssl
 import sys
 import urllib.request
 import urllib.error
@@ -23,12 +24,20 @@ import ftplib
 from tempfile import NamedTemporaryFile, gettempdir, TemporaryDirectory, mkdtemp
 from warnings import warn
 
+try:
+    import certifi
+except ImportError:
+    # certifi support is optional; when available it will be used for TLS/SSL
+    # downloads
+    certifi = None
+
 import astropy.config.paths
 from astropy import config as _config
 from astropy.utils.decorators import deprecated_renamed_argument
 from astropy.utils.exceptions import AstropyWarning
 from astropy.utils.introspection import find_current_module, resolve_name
 
+
 # Order here determines order in the autosummary
 __all__ = [
     'Conf', 'conf',
@@ -36,7 +45,7 @@ __all__ = [
     'get_readable_fileobj',
     'get_pkg_data_fileobj', 'get_pkg_data_filename',
     'get_pkg_data_contents', 'get_pkg_data_fileobjs',
-    'get_pkg_data_filenames',
+    'get_pkg_data_filenames', 'get_pkg_data_path',
     'is_url', 'is_url_in_cache', 'get_cached_urls',
     'cache_total_size', 'cache_contents',
     'export_download_cache', 'import_download_cache', 'import_file_to_cache',
@@ -47,6 +56,7 @@ __all__ = [
     'check_free_space_in_dir',
     'get_file_contents',
     'CacheMissingWarning',
+    "CacheDamaged"
 ]
 
 _dataurls_to_alias = {}
@@ -171,7 +181,7 @@ def get_readable_fileobj(name_or_obj, encoding=None, cache=False,
 
     Parameters
     ----------
-    name_or_obj : str or file-like object
+    name_or_obj : str or file-like
         The filename of the file to access (if given as a string), or
         the file-like object to access.
 
@@ -220,7 +230,7 @@ def get_readable_fileobj(name_or_obj, encoding=None, cache=False,
 
     Returns
     -------
-    file : readable file-like object
+    file : readable file-like
     """
 
     # close_fds is a list of file handles created by this function
@@ -229,7 +239,6 @@ def get_readable_fileobj(name_or_obj, encoding=None, cache=False,
     # passed in.  In that case it is not the responsibility of this
     # function to close it: doing so could result in a "double close"
     # and an "invalid file descriptor" exception.
-    PATH_TYPES = (str, pathlib.Path)
 
     close_fds = []
     delete_fds = []
@@ -238,11 +247,12 @@ def get_readable_fileobj(name_or_obj, encoding=None, cache=False,
         # use configfile default
         remote_timeout = conf.remote_timeout
 
-    # Get a file object to the content
-    if isinstance(name_or_obj, PATH_TYPES):
-        # name_or_obj could be a Path object if pathlib is available
-        name_or_obj = str(name_or_obj)
+    # name_or_obj could be an os.PathLike object
+    if isinstance(name_or_obj, os.PathLike):
+        name_or_obj = os.fspath(name_or_obj)
 
+    # Get a file object to the content
+    if isinstance(name_or_obj, str):
         is_url = _is_url(name_or_obj)
         if is_url:
             name_or_obj = download_file(
@@ -392,7 +402,7 @@ def get_file_contents(*args, **kwargs):
 
     Returns
     -------
-    content
+    object
         The content of the file (as requested by ``encoding``).
     """
     with get_readable_fileobj(*args, **kwargs) as f:
@@ -502,7 +512,7 @@ def get_pkg_data_fileobj(data_name, package=None, encoding=None, cache=True):
     get_pkg_data_filename : returns a local name for a file containing the data
     """  # noqa
 
-    datafn = _find_pkg_data_path(data_name, package=package)
+    datafn = get_pkg_data_path(data_name, package=package)
     if os.path.isdir(datafn):
         raise OSError("Tried to access a data file that's actually "
                       "a package data directory")
@@ -625,7 +635,7 @@ def get_pkg_data_filename(data_name, package=None, show_progress=True,
             return hashfn
     else:
         fs_path = os.path.normpath(data_name)
-        datafn = _find_pkg_data_path(fs_path, package=package)
+        datafn = get_pkg_data_path(fs_path, package=package)
         if os.path.isdir(datafn):
             raise OSError("Tried to access a data file that's actually "
                           "a package data directory")
@@ -759,7 +769,7 @@ def get_pkg_data_filenames(datadir, package=None, pattern='*'):
         ...
     """
 
-    path = _find_pkg_data_path(datadir, package=package)
+    path = get_pkg_data_path(datadir, package=package)
     if os.path.isfile(path):
         raise OSError(
             "Tried to access a data directory that's actually "
@@ -814,7 +824,7 @@ def get_pkg_data_fileobjs(datadir, package=None, pattern='*', encoding=None):
 
     Returns
     -------
-    fileobjs : iterator of file objects
+    fileobjs : iterator of file object
         File objects for each of the files on the local filesystem in
         *datadir* matching *pattern*.
 
@@ -871,18 +881,38 @@ def compute_hash(localfn):
     return h.hexdigest()
 
 
-def _find_pkg_data_path(data_name, package=None):
-    """
-    Look for data in the source-included data directories and return the
-    path.
-    """
+def get_pkg_data_path(*path, package=None):
+    """Get path from source-included data directories.
 
+    Parameters
+    ----------
+    *path : str
+        Name/location of the desired data file/directory.
+        May be a tuple of strings for ``os.path`` joining.
+
+    package : str or None, optional, keyword-only
+        If specified, look for a file relative to the given package, rather
+        than the calling module's package.
+
+    Returns
+    -------
+    path : str
+        Name/location of the desired data file/directory.
+
+    Raises
+    ------
+    ImportError
+        Given package or module is not importable.
+    RuntimeError
+        If the local data file is outside of the package's tree.
+
+    """
     if package is None:
         module = find_current_module(1, finddiff=['astropy.utils.data', 'contextlib'])
         if module is None:
             # not called from inside an astropy package.  So just pass name
             # through
-            return data_name
+            return os.path.join(*path)
 
         if not hasattr(module, '__package__') or not module.__package__:
             # The __package__ attribute may be missing or set to None; see
@@ -894,21 +924,23 @@ def _find_pkg_data_path(data_name, package=None):
         else:
             package = module.__package__
     else:
+        # package errors if it isn't a str
+        # so there is no need for checks in the containing if/else
         module = resolve_name(package)
 
-    rootpkgname = package.partition('.')[0]
-
-    rootpkg = resolve_name(rootpkgname)
-
+    # module path within package
     module_path = os.path.dirname(module.__file__)
-    path = os.path.join(module_path, data_name)
+    full_path = os.path.join(module_path, *path)
 
+    # Check that file is inside tree.
+    rootpkgname = package.partition('.')[0]
+    rootpkg = resolve_name(rootpkgname)
     root_dir = os.path.dirname(rootpkg.__file__)
-    if not _is_inside(path, root_dir):
+    if not _is_inside(full_path, root_dir):
         raise RuntimeError(f"attempted to get a local data file outside "
                            f"of the {rootpkgname} tree.")
 
-    return path
+    return full_path
 
 
 def _find_hash_fn(hexdigest, pkgname='astropy'):
@@ -1002,9 +1034,92 @@ class _FTPTLSHandler(urllib.request.FTPHandler):
                               persistent=False)
 
 
+@functools.lru_cache()
+def _build_urlopener(ftp_tls=False, ssl_context=None, allow_insecure=False):
+    """
+    Helper for building a `urllib.request.build_opener` which handles TLS/SSL.
+    """
+
+    ssl_context = dict(it for it in ssl_context) if ssl_context else {}
+    cert_chain = {}
+    if 'certfile' in ssl_context:
+        cert_chain.update({
+            'certfile': ssl_context.pop('certfile'),
+            'keyfile': ssl_context.pop('keyfile', None),
+            'password': ssl_context.pop('password', None)
+        })
+    elif 'password' in ssl_context or 'keyfile' in ssl_context:
+        raise ValueError(
+            "passing 'keyfile' or 'password' in the ssl_context argument "
+            "requires passing 'certfile' as well")
+
+    if 'cafile' not in ssl_context and certifi is not None:
+        ssl_context['cafile'] = certifi.where()
+
+    ssl_context = ssl.create_default_context(**ssl_context)
+
+    if allow_insecure:
+        ssl_context.check_hostname = False
+        ssl_context.verify_mode = ssl.CERT_NONE
+
+    if cert_chain:
+        ssl_context.load_cert_chain(**cert_chain)
+
+    https_handler = urllib.request.HTTPSHandler(context=ssl_context)
+
+    if ftp_tls:
+        urlopener = urllib.request.build_opener(_FTPTLSHandler(), https_handler)
+    else:
+        urlopener = urllib.request.build_opener(https_handler)
+
+    return urlopener
+
+
+def _try_url_open(source_url, timeout=None, http_headers=None, ftp_tls=False,
+                  ssl_context=None, allow_insecure=False):
+    """Helper for opening a URL while handling TLS/SSL verification issues."""
+
+    # Always try first with a secure connection
+    # _build_urlopener uses lru_cache, so the ssl_context argument must be
+    # converted to a hashshable type (a set of 2-tuples)
+    ssl_context = frozenset(ssl_context.items() if ssl_context else [])
+    urlopener = _build_urlopener(ftp_tls=ftp_tls, ssl_context=ssl_context,
+                                 allow_insecure=False)
+    req = urllib.request.Request(source_url, headers=http_headers)
+
+    try:
+        return urlopener.open(req, timeout=timeout)
+    except urllib.error.URLError as exc:
+        reason = exc.reason
+        if (isinstance(reason, ssl.SSLError)
+                and reason.reason == 'CERTIFICATE_VERIFY_FAILED'):
+            msg = (f'Verification of TLS/SSL certificate at {source_url} '
+                   f'failed: this can mean either the server is '
+                   f'misconfigured or your local root CA certificates are '
+                   f'out-of-date; in the latter case this can usually be '
+                   f'addressed by installing the Python package "certifi" '
+                   f'(see the documentation for astropy.utils.data.download_url)')
+            if not allow_insecure:
+                msg += (f' or in both cases you can work around this by '
+                        f'passing allow_insecure=True, but only if you '
+                        f'understand the implications; the original error '
+                        f'was: {reason}')
+                raise urllib.error.URLError(msg)
+            else:
+                msg += '. Re-trying with allow_insecure=True.'
+                warn(msg, AstropyWarning)
+                # Try again with a new urlopener allowing insecure connections
+                urlopener = _build_urlopener(ftp_tls=ftp_tls,
+                        ssl_context=ssl_context, allow_insecure=True)
+                return urlopener.open(req, timeout=timeout)
+
+        raise
+
+
 def _download_file_from_source(source_url, show_progress=True, timeout=None,
                                remote_url=None, cache=False, pkgname='astropy',
-                               http_headers=None, ftp_tls=None):
+                               http_headers=None, ftp_tls=None,
+                               ssl_context=None, allow_insecure=False):
     from astropy.utils.console import ProgressBarOrSpinner
 
     if timeout == 0:
@@ -1042,13 +1157,10 @@ def _download_file_from_source(source_url, show_progress=True, timeout=None,
                 ftp_tls = True
             else:
                 raise
-    if ftp_tls:
-        urlopener = urllib.request.build_opener(_FTPTLSHandler())
-    else:
-        urlopener = urllib.request.build_opener()
 
-    req = urllib.request.Request(source_url, headers=http_headers)
-    with urlopener.open(req, timeout=timeout) as remote:
+    with _try_url_open(source_url, timeout=timeout, http_headers=http_headers,
+            ftp_tls=ftp_tls, ssl_context=ssl_context,
+            allow_insecure=allow_insecure) as remote:
         info = remote.info()
         try:
             size = int(info['Content-Length'])
@@ -1102,7 +1214,8 @@ def _download_file_from_source(source_url, show_progress=True, timeout=None,
 
 
 def download_file(remote_url, cache=False, show_progress=True, timeout=None,
-                  sources=None, pkgname='astropy', http_headers=None):
+                  sources=None, pkgname='astropy', http_headers=None,
+                  ssl_context=None, allow_insecure=False):
     """Downloads a URL and optionally caches the result.
 
     It returns the filename of a file containing the URL's contents.
@@ -1164,6 +1277,28 @@ def download_file(remote_url, cache=False, show_progress=True, timeout=None,
         ``User-Agent: some_value`` and ``Accept: */*``, where ``some_value``
         is set by ``astropy.utils.data.conf.default_http_user_agent``.
 
+    ssl_context : dict, optional
+        Keyword arguments to pass to `ssl.create_default_context` when
+        downloading from HTTPS or TLS+FTP sources.  This can be used provide
+        alternative paths to root CA certificates.  Additionally, if the key
+        ``'certfile'`` and optionally ``'keyfile'`` and ``'password'`` are
+        included, they are passed to `ssl.SSLContext.load_cert_chain`.  This
+        can be used for performing SSL/TLS client certificate authentication
+        for servers that require it.
+
+    allow_insecure : bool, optional
+        Allow downloading files over a TLS/SSL connection even when the server
+        certificate verification failed.  When set to `True` the potentially
+        insecure download is allowed to proceed, but an
+        `~astropy.utils.exceptions.AstropyWarning` is issued.  If you are
+        frequently getting certificate verification warnings, consider
+        installing or upgrading `certifi`_ package, which provides frequently
+        updated certificates for common root CAs (i.e., a set similar to those
+        used by web browsers).  If installed, Astropy will use it
+        automatically.
+
+        .. _certifi: https://pypi.org/project/certifi/
+
     Returns
     -------
     local_path : str
@@ -1226,7 +1361,9 @@ def download_file(remote_url, cache=False, show_progress=True, timeout=None,
                     cache=cache,
                     remote_url=remote_url,
                     pkgname=pkgname,
-                    http_headers=http_headers)
+                    http_headers=http_headers,
+                    ssl_context=ssl_context,
+                    allow_insecure=allow_insecure)
             # Success!
             break
 
@@ -1646,7 +1783,7 @@ def check_download_cache(check_hashes=False, pkgname='astropy'):
 
     Parameters
     ----------
-    pkgname : `str`, optional
+    pkgname : str, optional
         The package name to use to locate the download cache. i.e. for
         ``pkgname='astropy'`` the default cache location is
         ``~/.astropy/cache``.
@@ -1658,7 +1795,7 @@ def check_download_cache(check_hashes=False, pkgname='astropy'):
 
     Raises
     ------
-    CacheDamaged
+    `~astropy.utils.data.CacheDamaged`
         To indicate a problem with the cache contents; the exception contains
         a ``.bad_files`` attribute containing a set of filenames to allow the
         user to use `clear_download_cache` to remove the offending items.
