@@ -113,11 +113,15 @@ class Conf(_config.ConfigNamespace):
     auto_download = _config.ConfigItem(
         True,
         'Enable auto-downloading of the latest IERS data.  If set to False '
-        'then the local IERS-B and leap-second files will be used by default. '
-        'Default is True.')
+        'then the local IERS-B file will be used by default (even if the '
+        'full IERS file with predictions was already downloaded and cached). '
+        'This parameter also controls whether internet resources will be '
+        'queried to update the leap second table if the installed version is '
+        'out of date. Default is True.')
     auto_max_age = _config.ConfigItem(
         30.0,
         'Maximum age (days) of predictive data before auto-downloading. '
+        'See "Auto refresh behavior" in astropy.utils.iers documentation for details.'
         'Default is 30.')
     iers_auto_url = _config.ConfigItem(
         IERS_A_URL,
@@ -175,7 +179,8 @@ class IERS(QTable):
 
         Returns
         -------
-        An IERS table class instance
+        IERS
+            An IERS table class instance
 
         Notes
         -----
@@ -224,7 +229,7 @@ class IERS(QTable):
 
         Parameters
         ----------
-        jd1 : float, array, or Time
+        jd1 : float, array, or `~astropy.time.Time`
             first part of two-part JD, or Time object
         jd2 : float or array, optional
             second part of two-part JD.
@@ -251,7 +256,7 @@ class IERS(QTable):
 
         Parameters
         ----------
-        jd1 : float, float array, or Time object
+        jd1 : float, array of float, or `~astropy.time.Time` object
             first part of two-part JD, or Time object
         jd2 : float or float array, optional
             second part of two-part JD.
@@ -281,7 +286,7 @@ class IERS(QTable):
 
         Parameters
         ----------
-        jd1 : float, float array, or Time object
+        jd1 : float, array of float, or `~astropy.time.Time` object
             first part of two-part JD, or Time object
         jd2 : float or float array, optional
             second part of two-part JD (default 0., ignored if jd1 is Time)
@@ -292,9 +297,9 @@ class IERS(QTable):
 
         Returns
         -------
-        D_x : Quantity with angle units
-            x component of CIP correction for the requested times
-        D_y : Quantity with angle units
+        D_x : `~astropy.units.Quantity` ['angle']
+            x component of CIP correction for the requested times.
+        D_y : `~astropy.units.Quantity` ['angle']
             y component of CIP correction for the requested times
         status : int or int array
             Status values (if ``return_status``=``True``)::
@@ -312,7 +317,7 @@ class IERS(QTable):
 
         Parameters
         ----------
-        jd1 : float, float array, or Time object
+        jd1 : float, array of float, or `~astropy.time.Time` object
             first part of two-part JD, or Time object
         jd2 : float or float array, optional
             second part of two-part JD.
@@ -324,10 +329,10 @@ class IERS(QTable):
 
         Returns
         -------
-        PM_x : Quantity with angle units
-            x component of polar motion for the requested times
-        PM_y : Quantity with angle units
-            y component of polar motion for the requested times
+        PM_x : `~astropy.units.Quantity` ['angle']
+            x component of polar motion for the requested times.
+        PM_y : `~astropy.units.Quantity` ['angle']
+            y component of polar motion for the requested times.
         status : int or int array
             Status values (if ``return_status``=``True``)::
             ``iers.FROM_IERS_B``
@@ -356,6 +361,9 @@ class IERS(QTable):
         if is_scalar:
             mjd = np.array([mjd])
             utc = np.array([utc])
+        elif mjd.size == 0:
+            # Short-cut empty input.
+            return np.array([])
 
         self._refresh_table_as_needed(mjd)
 
@@ -653,7 +661,8 @@ class IERS_Auto(IERS_A):
 
         Returns
         -------
-        `~astropy.table.QTable` instance with IERS (Earth rotation) data columns
+        `~astropy.table.QTable` instance
+            With IERS (Earth rotation) data columns
 
         """
         if not conf.auto_download:
@@ -872,6 +881,11 @@ class LeapSeconds(QTable):
     ``iers.LEAP_SECONDS_LIST_URL``.  Many systems also store a version
     of ``leap-seconds.list`` for use with ``ntp`` (e.g., on Debian/Ubuntu
     systems, ``/usr/share/zoneinfo/leap-seconds.list``).
+
+    To prevent querying internet resources if the available local leap second
+    file(s) are out of date, set ``iers.conf.auto_download = False``. This
+    must be done prior to performing any ``Time`` scale transformations related
+    to UTC (e.g. converting from UTC to TAI).
     """
     # Note: Time instances in this class should use scale='tai' to avoid
     # needing leap seconds in their creation or interpretation.
@@ -891,7 +905,7 @@ class LeapSeconds(QTable):
 
         Parameters
         ----------
-        file : path, or None
+        file : path-like or None
             Full local or network path to the file holding leap-second data,
             for passing on to the various ``from_`` class methods.
             If 'erfa', return the data used by the ERFA library.
@@ -952,7 +966,7 @@ class LeapSeconds(QTable):
 
         Parameters
         ----------
-        files : list of path, optional
+        files : list of path-like, optional
             List of files/URLs to attempt to open.  By default, uses
             ``cls._auto_open_files``.
 
@@ -1052,7 +1066,7 @@ class LeapSeconds(QTable):
 
         Parameters
         ----------
-        file : path, optional
+        file : path-like, optional
             Full local or network path to the file holding leap-second data
             in a format consistent with that used by IERS.  By default, uses
             ``iers.IERS_LEAP_SECOND_FILE``.
@@ -1071,7 +1085,7 @@ class LeapSeconds(QTable):
 
         Parameters
         ----------
-        file : path, optional
+        file : path-like, optional
             Full local or network path to the file holding leap-second data
             in a format consistent with that used by IETF.  Up to date versions
             can be retrieved from ``iers.IETF_LEAP_SECOND_URL``.
