@@ -29,6 +29,7 @@ import pytest
 from astropy import units as _u  # u is taken
 from astropy.config import paths
 import astropy.utils.data
+from astropy.utils.exceptions import AstropyWarning
 from astropy.utils.data import (
     CacheMissingWarning,
     CacheDamaged,
@@ -55,29 +56,18 @@ from astropy.utils.data import (
     check_free_space_in_dir,
     _get_download_cache_loc,
     download_files_in_parallel,
-    is_url
+    is_url,
+    get_pkg_data_path
 )
 
-TRAVIS = os.environ.get('TRAVIS', False) == "true"
 CI = os.environ.get('CI', False) == "true"
 TESTURL = "http://www.astropy.org"
 TESTURL2 = "http://www.astropy.org/about.html"
+TESTURL_SSL = "https://www.astropy.org"
 TESTLOCAL = get_pkg_data_filename(os.path.join("data", "local.dat"))
 
 # NOTE: Python can be built without bz2 or lzma.
-try:
-    import bz2  # noqa
-except ImportError:
-    HAS_BZ2 = False
-else:
-    HAS_BZ2 = True
-
-try:
-    import lzma  # noqa
-except ImportError:
-    HAS_XZ = False
-else:
-    HAS_XZ = True
+from astropy.utils.compat.optional_deps import HAS_BZ2, HAS_LZMA
 
 # For when we need "some" test URLs
 FEW = 5
@@ -390,7 +380,7 @@ def test_download_with_sources_and_bogus_original(
 
 
 @pytest.mark.skipif((3, 7) <= sys.version_info < (3, 8) or
-                    (sys.platform.startswith('win') and TRAVIS),
+                    (sys.platform.startswith('win') and CI),
                     reason="mystery segfault that is possibly bug #10008 "
                            "for python < 3.8, flaky cache error on Windows CI")
 def test_download_file_threaded_many(temp_cache, valid_urls):
@@ -411,7 +401,7 @@ def test_download_file_threaded_many(temp_cache, valid_urls):
 
 
 @pytest.mark.skipif((3, 7) <= sys.version_info < (3, 8) or
-                    (sys.platform.startswith('win') and TRAVIS),
+                    (sys.platform.startswith('win') and CI),
                     reason="mystery segfault that is possibly bug #10008 "
                            "for python < 3.8, flaky cache error on Windows CI")
 def test_threaded_segfault(valid_urls):
@@ -429,7 +419,7 @@ def test_threaded_segfault(valid_urls):
 
 
 @pytest.mark.skipif((3, 7) <= sys.version_info < (3, 8) or
-                    (sys.platform.startswith('win') and TRAVIS),
+                    (sys.platform.startswith('win') and CI),
                     reason="mystery segfault that is possibly bug #10008 "
                            "for python < 3.8, flaky cache error on Windows CI")
 def test_download_file_threaded_many_partial_success(
@@ -652,6 +642,26 @@ def test_download_cache():
     assert not os.path.isdir(lockdir), "Cache dir lock was not released!"
 
 
+@pytest.mark.remote_data(source="astropy")
+def test_download_certificate_verification_failed():
+    """Tests for https://github.com/astropy/astropy/pull/10434"""
+
+    # First test the expected exception when download fails due to a
+    # certificate verification error; we simulate this by passing a bogus
+    # CA directory to the ssl_context argument
+    ssl_context = {'cafile': None, 'capath': '/does/not/exist'}
+    msg = f'Verification of TLS/SSL certificate at {TESTURL_SSL} failed'
+    with pytest.raises(urllib.error.URLError, match=msg):
+        download_file(TESTURL_SSL, cache=False, ssl_context=ssl_context)
+
+    with pytest.warns(AstropyWarning, match=msg) as warning_lines:
+        fnout = download_file(TESTURL_SSL, cache=False,
+                ssl_context=ssl_context, allow_insecure=True)
+
+    assert len(warning_lines) == 1
+    assert os.path.isfile(fnout)
+
+
 def test_download_cache_after_clear(tmpdir, temp_cache, valid_urls):
     testurl, contents = next(valid_urls)
     # Test issues raised in #4427 with clear_download_cache() without a URL,
@@ -904,12 +914,21 @@ def test_find_invalid():
         )
 
 
+@pytest.mark.parametrize("package", [None, "astropy", "numpy"])
+def test_get_invalid(package):
+    """Test can create a file path to an invalid file."""
+    path = get_pkg_data_path("kjfrhgjkla", "hgiulrhgiu", package=package)
+    assert not os.path.isfile(path)
+    assert not os.path.isdir(path)
+
+
 # Package data functions
 @pytest.mark.parametrize(
     ("filename"), ["local.dat", "local.dat.gz", "local.dat.bz2", "local.dat.xz"]
 )
 def test_local_data_obj(filename):
-    if (not HAS_BZ2 and "bz2" in filename) or (not HAS_XZ and "xz" in filename):
+    if ((not HAS_BZ2 and "bz2" in filename) or
+            (not HAS_LZMA and "xz" in filename)):
         with pytest.raises(ValueError) as e:
             with get_pkg_data_fileobj(
                 os.path.join("data", filename), encoding="binary"
@@ -958,7 +977,7 @@ def test_local_data_obj_invalid(bad_compressed):
     # they're not local anymore: they just live in a temporary directory
     # created by pytest. However, we can still use get_readable_fileobj for the
     # test.
-    if (not HAS_BZ2 and is_bz2) or (not HAS_XZ and is_xz):
+    if (not HAS_BZ2 and is_bz2) or (not HAS_LZMA and is_xz):
         with pytest.raises(ModuleNotFoundError,
                            match=r'does not provide the [lb]z[2m]a? module\.'):
             with get_readable_fileobj(bad_compressed, encoding="binary") as f:
@@ -1116,7 +1135,7 @@ def test_data_noastropy_fallback(monkeypatch):
         ),
         pytest.param(
             "unicode.txt.xz",
-            marks=pytest.mark.xfail(not HAS_XZ, reason="no lzma support"),
+            marks=pytest.mark.xfail(not HAS_LZMA, reason="no lzma support"),
         ),
     ],
 )
@@ -1711,7 +1730,7 @@ def test_download_file_wrong_size(monkeypatch):
     def mockurl(remote_url, timeout=None):
         yield MockURL()
 
-    def mockurl_builder(tlscontext=None):
+    def mockurl_builder(*args, tlscontext=None, **kwargs):
         mock_opener = type('MockOpener', (object,), {})()
         mock_opener.open = mockurl
         return mock_opener
@@ -1726,7 +1745,7 @@ def test_download_file_wrong_size(monkeypatch):
         def read(self, length=None):
             return self.reader.read(length)
 
-    monkeypatch.setattr(urllib.request, "build_opener", mockurl_builder)
+    monkeypatch.setattr(astropy.utils.data, "_build_urlopener", mockurl_builder)
 
     with pytest.raises(urllib.error.ContentTooShortError):
         report_length = 1024
@@ -2128,7 +2147,7 @@ def test_clear_download_cache_variants(temp_cache, valid_urls):
     assert not is_url_in_cache(u)
 
 
-@pytest.mark.skipif("TRAVIS", reason="Flaky on Travis CI")
+@pytest.mark.skipif("CI", reason="Flaky on CI")
 @pytest.mark.remote_data
 def test_ftp_tls_auto(temp_cache):
     url = "ftp://anonymous:mail%40astropy.org@gdc.cddis.eosdis.nasa.gov/pub/products/iers/finals2000A.all"  # noqa
@@ -2170,7 +2189,8 @@ def test_download_ftp_file_properly_handles_socket_error():
     possible_msgs = ['Name or service not known',
                      'nodename nor servname provided, or not known',
                      'getaddrinfo failed',
-                     'Temporary failure in name resolution']
+                     'Temporary failure in name resolution',
+                     'No address associated with hostname']
     for cur_msg in possible_msgs:
         if cur_msg in errmsg:
             found_msg = True
