@@ -3,7 +3,7 @@
 import json
 import locale
 import os
-import socket
+import urllib.error
 from datetime import datetime
 
 import pytest
@@ -29,9 +29,10 @@ def test_signal_number_to_name_no_failure():
 @pytest.mark.remote_data
 def test_api_lookup():
     try:
-        strurl = misc.find_api_page('astropy.utils.misc', 'dev', False, timeout=3)
-        objurl = misc.find_api_page(misc, 'dev', False, timeout=3)
-    except socket.timeout:
+        strurl = misc.find_api_page('astropy.utils.misc', 'dev', False,
+                                    timeout=5)
+        objurl = misc.find_api_page(misc, 'dev', False, timeout=5)
+    except urllib.error.URLError:
         if os.environ.get('CI', False):
             pytest.xfail('Timed out in CI')
         else:
@@ -46,7 +47,7 @@ def test_api_lookup():
 
 
 def test_skip_hidden():
-    path = data._find_pkg_data_path('data')
+    path = data.get_pkg_data_path('data')
     for root, dirs, files in os.walk(path):
         assert '.hidden_file.txt' in files
         assert 'local.dat' in files
@@ -85,40 +86,12 @@ def test_JsonCustomEncoder():
     assert newd == tmpd
 
 
-@pytest.mark.filterwarnings("ignore")
-def test_inherit_docstrings():
-    class Base(metaclass=misc.InheritDocstrings):
-        def __call__(self, *args):
-            "FOO"
-            pass
-
-        @property
-        def bar(self):
-            "BAR"
-            pass
-
-    class Subclass(Base):
-        def __call__(self, *args):
-            pass
-
-        @property
-        def bar(self):
-            return 42
-
-    if Base.__call__.__doc__ is not None:
-        # TODO: Maybe if __doc__ is None this test should be skipped instead?
-        assert Subclass.__call__.__doc__ == "FOO"
-
-    if Base.bar.__doc__ is not None:
-        assert Subclass.bar.__doc__ == "BAR"
-
-
 def test_set_locale():
     # First, test if the required locales are available
     current = locale.setlocale(locale.LC_ALL)
     try:
-        locale.setlocale(locale.LC_ALL, 'en_US')
-        locale.setlocale(locale.LC_ALL, 'de_DE')
+        locale.setlocale(locale.LC_ALL, 'en_US.utf8')
+        locale.setlocale(locale.LC_ALL, 'fr_FR.utf8')
     except locale.Error as e:
         pytest.skip(f'Locale error: {e}')
     finally:
@@ -127,11 +100,11 @@ def test_set_locale():
     date = datetime(2000, 10, 1, 0, 0, 0)
     day_mon = date.strftime('%a, %b')
 
-    with misc._set_locale('en_US'):
+    with misc._set_locale('en_US.utf8'):
         assert date.strftime('%a, %b') == 'Sun, Oct'
 
-    with misc._set_locale('de_DE'):
-        assert date.strftime('%a, %b') == 'So, Okt'
+    with misc._set_locale('fr_FR.utf8'):
+        assert date.strftime('%a, %b') == 'dim., oct.'
 
     # Back to original
     assert date.strftime('%a, %b') == day_mon
