@@ -34,7 +34,8 @@ def add_stokes_axis_to_wcs(wcs, add_before_ind):
 
     Returns
     -------
-    A new `~astropy.wcs.WCS` instance with an additional axis
+    `~astropy.wcs.WCS`
+        A new `~astropy.wcs.WCS` instance with an additional axis
     """
 
     inds = [i + 1 for i in range(wcs.wcs.naxis)]
@@ -315,7 +316,7 @@ def proj_plane_pixel_scales(wcs):
 
     Returns
     -------
-    scale : `~numpy.ndarray`
+    scale : ndarray
         A vector (`~numpy.ndarray`) of projection plane increments
         corresponding to each pixel side (axis). The units of the returned
         results are the same as the units of `~astropy.wcs.Wcsprm.cdelt`,
@@ -573,7 +574,7 @@ def pixel_to_skycoord(xp, yp, wcs, origin=0, mode='all', cls=None):
 
     Parameters
     ----------
-    xp, yp : float or `numpy.ndarray`
+    xp, yp : float or ndarray
         The coordinates to convert.
     wcs : `~astropy.wcs.WCS`
         The WCS transformation to use.
@@ -589,8 +590,8 @@ def pixel_to_skycoord(xp, yp, wcs, origin=0, mode='all', cls=None):
 
     Returns
     -------
-    coords : Whatever ``cls`` is (a subclass of `~astropy.coordinates.SkyCoord`)
-        The celestial coordinates
+    coords : `~astropy.coordinates.SkyCoord` subclass
+        The celestial coordinates. Whatever ``cls`` type is.
 
     See Also
     --------
@@ -970,7 +971,7 @@ def fit_wcs_from_points(xy, world_coords, proj_point='center',
     keywords in the input might cause unexpected behavior.
 
     Notes
-    ------
+    -----
     - The fiducial point for the spherical projection can be set to 'center'
       to use the mean position of input sky coordinates, or as an
       `~astropy.coordinates.SkyCoord` object.
@@ -985,7 +986,7 @@ def fit_wcs_from_points(xy, world_coords, proj_point='center',
 
     Parameters
     ----------
-    xy : tuple of two `numpy.ndarray`
+    xy : (`numpy.ndarray`, `numpy.ndarray`) tuple
         x & y pixel coordinates.
     world_coords : `~astropy.coordinates.SkyCoord`
         Skycoord object with world coordinates.
@@ -1058,8 +1059,12 @@ def fit_wcs_from_points(xy, world_coords, proj_point='center',
     if (type(sip_degree) != type(None)) and (type(sip_degree) != int):
         raise ValueError("sip_degree must be None, or integer.")
 
+    # compute bounding box for sources in image coordinates:
+    xpmin, xpmax, ypmin, ypmax = xp.min(), xp.max(), yp.min(), yp.max()
+
     # set pixel_shape to span of input points
-    wcs.pixel_shape = (xp.max()+1-xp.min(), yp.max()+1-yp.min())
+    wcs.pixel_shape = (1 if xpmax <= 0.0 else int(np.ceil(xpmax)),
+                       1 if ypmax <= 0.0 else int(np.ceil(ypmax)))
 
     # determine CRVAL from input
     close = lambda l, p: p[np.argmin(np.abs(l))]
@@ -1070,28 +1075,29 @@ def fit_wcs_from_points(xy, world_coords, proj_point='center',
         sep = sc1.separation(sc2)
         midpoint_sc = sc1.directional_offset_by(pa, sep/2)
         wcs.wcs.crval = ((midpoint_sc.data.lon.deg, midpoint_sc.data.lat.deg))
-        wcs.wcs.crpix = ((xp.max()+xp.min())/2., (yp.max()+yp.min())/2.)
+        wcs.wcs.crpix = ((xpmax + xpmin) / 2., (ypmax + ypmin) / 2.)
     else:  # convert units, initial guess for crpix
         proj_point.transform_to(world_coords)
         wcs.wcs.crval = (proj_point.data.lon.deg, proj_point.data.lat.deg)
-        wcs.wcs.crpix = (close(lon-wcs.wcs.crval[0], xp),
-                         close(lon-wcs.wcs.crval[1], yp))
+        wcs.wcs.crpix = (close(lon - wcs.wcs.crval[0], xp + 1),
+                         close(lon - wcs.wcs.crval[1], yp + 1))
 
     # fit linear terms, assign to wcs
     # use (1, 0, 0, 1) as initial guess, in case input wcs was passed in
     # and cd terms are way off.
     # Use bounds to require that the fit center pixel is on the input image
-    xpmin, xpmax, ypmin, ypmax = xp.min(), xp.max(), yp.min(), yp.max()
     if xpmin == xpmax:
         xpmin, xpmax = xpmin - 0.5, xpmax + 0.5
     if ypmin == ypmax:
         ypmin, ypmax = ypmin - 0.5, ypmax + 0.5
 
     p0 = np.concatenate([wcs.wcs.cd.flatten(), wcs.wcs.crpix.flatten()])
-    fit = least_squares(_linear_wcs_fit, p0,
-                        args=(lon, lat, xp, yp, wcs),
-                        bounds=[[-np.inf, -np.inf, -np.inf, -np.inf, xpmin, ypmin],
-                                [ np.inf, np.inf, np.inf, np.inf, xpmax, ypmax]])
+    fit = least_squares(
+        _linear_wcs_fit, p0,
+        args=(lon, lat, xp, yp, wcs),
+        bounds=[[-np.inf, -np.inf, -np.inf, -np.inf, xpmin + 1, ypmin + 1],
+                [ np.inf, np.inf, np.inf, np.inf, xpmax + 1, ypmax + 1]]
+    )
     wcs.wcs.crpix = np.array(fit.x[4:6])
     wcs.wcs.cd = np.array(fit.x[0:4].reshape((2, 2)))
 
@@ -1101,16 +1107,18 @@ def fit_wcs_from_points(xy, world_coords, proj_point='center',
         if '-SIP' not in wcs.wcs.ctype[0]:
             wcs.wcs.ctype = [x + '-SIP' for x in wcs.wcs.ctype]
 
-        coef_names = ['{0}_{1}'.format(i, j) for i in range(degree+1)
+        coef_names = [f'{i}_{j}' for i in range(degree+1)
                       for j in range(degree+1) if (i+j) < (degree+1) and
                       (i+j) > 1]
         p0 = np.concatenate((np.array(wcs.wcs.crpix), wcs.wcs.cd.flatten(),
                              np.zeros(2*len(coef_names))))
 
-        fit = least_squares(_sip_fit, p0,
-                            args=(lon, lat, xp, yp, wcs, degree, coef_names),
-                            bounds=[[xpmin, ypmin] + [-np.inf]*(4 + 2*len(coef_names)),
-                                    [xpmax, ypmax] + [np.inf]*(4 + 2*len(coef_names))])
+        fit = least_squares(
+            _sip_fit, p0,
+            args=(lon, lat, xp, yp, wcs, degree, coef_names),
+            bounds=[[xpmin + 1, ypmin + 1] + [-np.inf]*(4 + 2*len(coef_names)),
+                    [xpmax + 1, ypmax + 1] + [np.inf]*(4 + 2*len(coef_names))]
+        )
         coef_fit = (list(fit.x[6:6+len(coef_names)]),
                     list(fit.x[6+len(coef_names):]))
 
